Module pattern

Module pattern 

Structs

Atom
A single pattern component that is matched with a single Matcher function
MultiPattern
Pattern
A text pattern made up of (potentially multiple) atoms.

Enums

AtomKind
The kind of matching algorithm to run for an atom.
CaseMatching
How to treat a case mismatch between two characters.
Normalization
How to handle unicode normalization,