pub struct MultiPattern { /* private fields */ }Implementations
Sourceimpl MultiPattern
impl MultiPattern
Sourcepub fn reparse(
&mut self,
column: usize,
new_text: &str,
case_matching: CaseMatching,
normalization: Normalization,
append: bool,
)
pub fn reparse( &mut self, column: usize, new_text: &str, case_matching: CaseMatching, normalization: Normalization, append: bool, )
Reparses a column. By specifying append the caller promises that text passed
to the previous reparse invocation is a prefix of new_text. This enables
additional optimizations but can lead to missing matches if an incorrect value
is passed.
pub fn column_pattern(&self, column: usize) -> &Pattern
pub fn score( &self, haystack: &[Utf32String], matcher: &mut Matcher, ) -> Option<u32>
pub fn is_empty(&self) -> bool