Structs
- Atom
- A single pattern component that is matched with a single
Matcherfunction - Multi
Pattern - Pattern
- A text pattern made up of (potentially multiple) atoms.
Enums
- Atom
Kind - The kind of matching algorithm to run for an atom.
- Case
Matching - How to treat a case mismatch between two characters.
- Normalization
- How to handle unicode normalization,